@@ -1,5 +1,5 @@
 package Test::Inter;
-# Copyright (c) 2010-2010 Sullivan Beck. All rights reserved.
+# Copyright (c) 2010-2011 Sullivan Beck. All rights reserved.
 # This program is free software; you can redistribute it and/or modify it
 # under the same terms as Perl itself.
 
@@ -9,9 +9,11 @@ require 5.004;
 
 use warnings;
 use strict;
+use File::Basename;
+use IO::File;
 
-use vars qw($VERSION);
-$VERSION = '1.00';
+our($VERSION);
+$VERSION = '1.03';
 
 ###############################################################################
 # BASE METHODS
@@ -47,6 +49,7 @@ sub new {
                                      # (this should only be done when
                                      # running as an interactive script)
                'mode'     => 'test', # mode to run script in
+               'width'    => 80,     # width of terminal
                'features' => {},     # a list of available features
 
                'skipall'  => '',     # the reason for skipping all
@@ -64,7 +67,7 @@ sub new {
 
    # Handle options, environment variables, global variables
 
-   my @opts = qw(start end testnum plan abort quiet mode skip_all);
+   my @opts = qw(start end testnum plan abort quiet mode width skip_all);
    my %o    = map { $_,1 } @opts;
 
    no strict 'refs';
@@ -105,9 +108,7 @@ sub new {
    my($TDIR,@LIBDIR);
    if (-f "$0") {
       my $COM = $0;
-      $COM    =~ s/^.*\///;
-      $TDIR   = $0;
-      $TDIR   =~ s/\/?$COM$//;
+      $TDIR   = dirname($COM);
       $TDIR   = '.'  if (! $TDIR);
    } elsif (-d 't') {
       $TDIR   = 't';
@@ -211,6 +212,12 @@ sub mode {
    $$self{'mode'} = $val;
 }
 
+sub width {
+   my($self,$val) = @_;
+   $val = 0  if (! $val);
+   $$self{'width'} = $val;
+}
+
 sub skip_all {
    my($self,$reason,@features) = @_;
 
@@ -714,10 +721,16 @@ sub _cmp_result {
 sub _stringify {
    my($self,$s) = @_;
 
-   my($str) = $self->__stringify($s);
-   $str = substr($str,0,60)  if (length($str)>60);
+   my($str)   = $self->__stringify($s);
+   my($width) = $$self{'width'};
+   if ($width) {
+      $width -= 21;    # The leading string
+      $width  = 10  if ($width < 10);
+      $str = substr($str,0,$width)  if (length($str)>$width);
+   }
    return $str;
 }
+
 sub __stringify {
    my($self,$s) = @_;
 
@@ -878,9 +891,15 @@ sub file {
 
    # Test each line
 
-   my @out = `cat $output`;
+   my $in = new IO::File;
+   $in->open($output);
+   my @out = <$in>;
+   $in->close();
    chomp(@out);
-   my @exp = `cat $expected`;
+
+   $in->open($expected);
+   my @exp = <$in>;
+   $in->close();
    chomp(@exp);
    unlink($output);
 
